# Ecosystems Hub Async web server package

## Requirements
- Python >= 3.6.x

## Concept
The package includes an implementation of web app service library to handle requests asynchronously.

Please note that this an interim solution and the packgage can be no more supported or removed anytime.